/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM nsINNTPNewsgroupList.idl
 */

#ifndef __gen_nsINNTPNewsgroupList_h__
#define __gen_nsINNTPNewsgroupList_h__


#ifndef __gen_nsISupports_h__
#include "nsISupports.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif
class nsIMsgNewsFolder; /* forward declaration */

class nsINntpUrl; /* forward declaration */

class nsIMsgWindow; /* forward declaration */


/* starting interface:    nsINNTPNewsgroupList */
#define NS_INNTPNEWSGROUPLIST_IID_STR "579aa17b-4c77-465d-8eb6-feaa927cb19c"

#define NS_INNTPNEWSGROUPLIST_IID \
  {0x579aa17b, 0x4c77, 0x465d, \
    { 0x8e, 0xb6, 0xfe, 0xaa, 0x92, 0x7c, 0xb1, 0x9c }}

/**
 * A utility class for nsINNTPProtocol that handles the list of new headers.
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsINNTPNewsgroupList : public nsISupports {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_INNTPNEWSGROUPLIST_IID)

  /* void initialize (in nsINntpUrl runningURL, in nsIMsgNewsFolder newsFolder); */
  NS_SCRIPTABLE NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) = 0;

  /* long getRangeOfArtsToDownload (in nsIMsgWindow aMsgWindow, in long first_message, in long last_message, in long maxextra, out long real_first_message, out long real_last_message); */
  NS_SCRIPTABLE NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message NS_OUTPARAM, PRInt32 *real_last_message NS_OUTPARAM, PRInt32 *_retval NS_OUTPARAM) = 0;

  /* void addToKnownArticles (in long first_message, in long last_message); */
  NS_SCRIPTABLE NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) = 0;

  /**
   * Initializes the internal state to get the messages.
   *
   * This method should be called before sending the line
   * <tt>XOVER @arg first_message-@arg last_message</tt> to the server.
   *
   * @param first_message  The first message of the download range.
   * @param last_message   The last message of the download range.
   */
  /* void initXOVER (in long first_message, in long last_message); */
  NS_SCRIPTABLE NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) = 0;

  /* void processXOVERLINE (in string line, out unsigned long status); */
  NS_SCRIPTABLE NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status NS_OUTPARAM) = 0;

  /* void resetXOVER (); */
  NS_SCRIPTABLE NS_IMETHOD ResetXOVER(void) = 0;

  /* void finishXOVERLINE (in long status, out long newstatus); */
  NS_SCRIPTABLE NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus NS_OUTPARAM) = 0;

  /**
   * Initalizes the state in preparation for a call to XHDR.
   *
   * @return               The next header to get, or an empty string if done.
   */
  /* ACString initXHDR (); */
  NS_SCRIPTABLE NS_IMETHOD InitXHDR(nsACString & _retval NS_OUTPARAM) = 0;

  /**
   * Processes a line of the server's response to XHDR.
   *
   * It will calculate the message number and other information itself, so the
   * unadulterated line itself should be sent.
   *
   * @param aLine          The line as sent from the server.
   */
  /* void processXHDRLine (in ACString aLine); */
  NS_SCRIPTABLE NS_IMETHOD ProcessXHDRLine(const nsACString & aLine) = 0;

  /**
   * Initalizes the internal state to process a HEAD command.
   *
   * This method should be called before sending the line
   * <tt>HEAD @arg aMessage</tt> to the server.
   *
   * @param aMessage       The message number that will be sent.
   */
  /* void initHEAD (in long aMessage); */
  NS_SCRIPTABLE NS_IMETHOD InitHEAD(PRInt32 aMessage) = 0;

  /**
   * Processes a line of the server's response to HEAD.
   *
   * This will not check for a quoted '.' at the beginning.
   *
   * @param aLine          The line the server sent.
   */
  /* void processHEADLine (in ACString aLine); */
  NS_SCRIPTABLE NS_IMETHOD ProcessHEADLine(const nsACString & aLine) = 0;

  /**
   * Manages the internal state if the call to HEAD failed.
   *
   * @param aMessage       The message key that caused the HEAD failure.
   */
  /* void HEADFailed (in long aMessage); */
  NS_SCRIPTABLE NS_IMETHOD HEADFailed(PRInt32 aMessage) = 0;

  /**
   * Calls the filters after all messages have been processed.
   *
   * This method also cleans out some internal state relating to the messages
   * that have been processed, so it should always be called at the end of
   * XOVER/XHDR/HEAD processing.
   */
  /* void callFilters (); */
  NS_SCRIPTABLE NS_IMETHOD CallFilters(void) = 0;

  /* attribute boolean getOldMessages; */
  NS_SCRIPTABLE NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) = 0;
  NS_SCRIPTABLE NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) = 0;

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsINNTPNewsgroupList, NS_INNTPNEWSGROUPLIST_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSINNTPNEWSGROUPLIST \
  NS_SCRIPTABLE NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder); \
  NS_SCRIPTABLE NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message NS_OUTPARAM, PRInt32 *real_last_message NS_OUTPARAM, PRInt32 *_retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message); \
  NS_SCRIPTABLE NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message); \
  NS_SCRIPTABLE NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD ResetXOVER(void); \
  NS_SCRIPTABLE NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD InitXHDR(nsACString & _retval NS_OUTPARAM); \
  NS_SCRIPTABLE NS_IMETHOD ProcessXHDRLine(const nsACString & aLine); \
  NS_SCRIPTABLE NS_IMETHOD InitHEAD(PRInt32 aMessage); \
  NS_SCRIPTABLE NS_IMETHOD ProcessHEADLine(const nsACString & aLine); \
  NS_SCRIPTABLE NS_IMETHOD HEADFailed(PRInt32 aMessage); \
  NS_SCRIPTABLE NS_IMETHOD CallFilters(void); \
  NS_SCRIPTABLE NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages); \
  NS_SCRIPTABLE NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages); 

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSINNTPNEWSGROUPLIST(_to) \
  NS_SCRIPTABLE NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) { return _to Initialize(runningURL, newsFolder); } \
  NS_SCRIPTABLE NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message NS_OUTPARAM, PRInt32 *real_last_message NS_OUTPARAM, PRInt32 *_retval NS_OUTPARAM) { return _to GetRangeOfArtsToDownload(aMsgWindow, first_message, last_message, maxextra, real_first_message, real_last_message, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) { return _to AddToKnownArticles(first_message, last_message); } \
  NS_SCRIPTABLE NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) { return _to InitXOVER(first_message, last_message); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status NS_OUTPARAM) { return _to ProcessXOVERLINE(line, status); } \
  NS_SCRIPTABLE NS_IMETHOD ResetXOVER(void) { return _to ResetXOVER(); } \
  NS_SCRIPTABLE NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus NS_OUTPARAM) { return _to FinishXOVERLINE(status, newstatus); } \
  NS_SCRIPTABLE NS_IMETHOD InitXHDR(nsACString & _retval NS_OUTPARAM) { return _to InitXHDR(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessXHDRLine(const nsACString & aLine) { return _to ProcessXHDRLine(aLine); } \
  NS_SCRIPTABLE NS_IMETHOD InitHEAD(PRInt32 aMessage) { return _to InitHEAD(aMessage); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessHEADLine(const nsACString & aLine) { return _to ProcessHEADLine(aLine); } \
  NS_SCRIPTABLE NS_IMETHOD HEADFailed(PRInt32 aMessage) { return _to HEADFailed(aMessage); } \
  NS_SCRIPTABLE NS_IMETHOD CallFilters(void) { return _to CallFilters(); } \
  NS_SCRIPTABLE NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) { return _to GetGetOldMessages(aGetOldMessages); } \
  NS_SCRIPTABLE NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) { return _to SetGetOldMessages(aGetOldMessages); } 

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSINNTPNEWSGROUPLIST(_to) \
  NS_SCRIPTABLE NS_IMETHOD Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder) { return !_to ? NS_ERROR_NULL_POINTER : _to->Initialize(runningURL, newsFolder); } \
  NS_SCRIPTABLE NS_IMETHOD GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message NS_OUTPARAM, PRInt32 *real_last_message NS_OUTPARAM, PRInt32 *_retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetRangeOfArtsToDownload(aMsgWindow, first_message, last_message, maxextra, real_first_message, real_last_message, _retval); } \
  NS_SCRIPTABLE NS_IMETHOD AddToKnownArticles(PRInt32 first_message, PRInt32 last_message) { return !_to ? NS_ERROR_NULL_POINTER : _to->AddToKnownArticles(first_message, last_message); } \
  NS_SCRIPTABLE NS_IMETHOD InitXOVER(PRInt32 first_message, PRInt32 last_message) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitXOVER(first_message, last_message); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessXOVERLINE(const char *line, PRUint32 *status NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->ProcessXOVERLINE(line, status); } \
  NS_SCRIPTABLE NS_IMETHOD ResetXOVER(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->ResetXOVER(); } \
  NS_SCRIPTABLE NS_IMETHOD FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->FinishXOVERLINE(status, newstatus); } \
  NS_SCRIPTABLE NS_IMETHOD InitXHDR(nsACString & _retval NS_OUTPARAM) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitXHDR(_retval); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessXHDRLine(const nsACString & aLine) { return !_to ? NS_ERROR_NULL_POINTER : _to->ProcessXHDRLine(aLine); } \
  NS_SCRIPTABLE NS_IMETHOD InitHEAD(PRInt32 aMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->InitHEAD(aMessage); } \
  NS_SCRIPTABLE NS_IMETHOD ProcessHEADLine(const nsACString & aLine) { return !_to ? NS_ERROR_NULL_POINTER : _to->ProcessHEADLine(aLine); } \
  NS_SCRIPTABLE NS_IMETHOD HEADFailed(PRInt32 aMessage) { return !_to ? NS_ERROR_NULL_POINTER : _to->HEADFailed(aMessage); } \
  NS_SCRIPTABLE NS_IMETHOD CallFilters(void) { return !_to ? NS_ERROR_NULL_POINTER : _to->CallFilters(); } \
  NS_SCRIPTABLE NS_IMETHOD GetGetOldMessages(PRBool *aGetOldMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->GetGetOldMessages(aGetOldMessages); } \
  NS_SCRIPTABLE NS_IMETHOD SetGetOldMessages(PRBool aGetOldMessages) { return !_to ? NS_ERROR_NULL_POINTER : _to->SetGetOldMessages(aGetOldMessages); } 

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsNNTPNewsgroupList : public nsINNTPNewsgroupList
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSINNTPNEWSGROUPLIST

  nsNNTPNewsgroupList();

private:
  ~nsNNTPNewsgroupList();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsNNTPNewsgroupList, nsINNTPNewsgroupList)

nsNNTPNewsgroupList::nsNNTPNewsgroupList()
{
  /* member initializers and constructor code */
}

nsNNTPNewsgroupList::~nsNNTPNewsgroupList()
{
  /* destructor code */
}

/* void initialize (in nsINntpUrl runningURL, in nsIMsgNewsFolder newsFolder); */
NS_IMETHODIMP nsNNTPNewsgroupList::Initialize(nsINntpUrl *runningURL, nsIMsgNewsFolder *newsFolder)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* long getRangeOfArtsToDownload (in nsIMsgWindow aMsgWindow, in long first_message, in long last_message, in long maxextra, out long real_first_message, out long real_last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::GetRangeOfArtsToDownload(nsIMsgWindow *aMsgWindow, PRInt32 first_message, PRInt32 last_message, PRInt32 maxextra, PRInt32 *real_first_message NS_OUTPARAM, PRInt32 *real_last_message NS_OUTPARAM, PRInt32 *_retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void addToKnownArticles (in long first_message, in long last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::AddToKnownArticles(PRInt32 first_message, PRInt32 last_message)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initXOVER (in long first_message, in long last_message); */
NS_IMETHODIMP nsNNTPNewsgroupList::InitXOVER(PRInt32 first_message, PRInt32 last_message)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void processXOVERLINE (in string line, out unsigned long status); */
NS_IMETHODIMP nsNNTPNewsgroupList::ProcessXOVERLINE(const char *line, PRUint32 *status NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void resetXOVER (); */
NS_IMETHODIMP nsNNTPNewsgroupList::ResetXOVER()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void finishXOVERLINE (in long status, out long newstatus); */
NS_IMETHODIMP nsNNTPNewsgroupList::FinishXOVERLINE(PRInt32 status, PRInt32 *newstatus NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* ACString initXHDR (); */
NS_IMETHODIMP nsNNTPNewsgroupList::InitXHDR(nsACString & _retval NS_OUTPARAM)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void processXHDRLine (in ACString aLine); */
NS_IMETHODIMP nsNNTPNewsgroupList::ProcessXHDRLine(const nsACString & aLine)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void initHEAD (in long aMessage); */
NS_IMETHODIMP nsNNTPNewsgroupList::InitHEAD(PRInt32 aMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void processHEADLine (in ACString aLine); */
NS_IMETHODIMP nsNNTPNewsgroupList::ProcessHEADLine(const nsACString & aLine)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void HEADFailed (in long aMessage); */
NS_IMETHODIMP nsNNTPNewsgroupList::HEADFailed(PRInt32 aMessage)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* void callFilters (); */
NS_IMETHODIMP nsNNTPNewsgroupList::CallFilters()
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* attribute boolean getOldMessages; */
NS_IMETHODIMP nsNNTPNewsgroupList::GetGetOldMessages(PRBool *aGetOldMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}
NS_IMETHODIMP nsNNTPNewsgroupList::SetGetOldMessages(PRBool aGetOldMessages)
{
    return NS_ERROR_NOT_IMPLEMENTED;
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsINNTPNewsgroupList_h__ */
